==> jc-1.4.0.tar.gz: java/awt/event/MouseEvent.h <==
// public class java.awt.event.MouseEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_InputEvent

#include "java/awt/event/InputEvent.h"

#ifndef _JC_java_awt_event_MouseEvent_H_
#define _JC_java_awt_event_MouseEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Point$object;
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseEvent$sub_refs	_jc_java_awt_event_MouseEvent$sub_refs;
typedef struct _jc_java_awt_event_MouseEvent$sub_nonrefs	_jc_java_awt_event_MouseEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseEvent$refs	_jc_java_awt_event_MouseEvent$refs;
typedef struct _jc_java_awt_event_MouseEvent$nonrefs	_jc_java_awt_event_MouseEvent$nonrefs;
typedef struct _jc_java_awt_event_MouseEvent$object	_jc_java_awt_event_MouseEvent$object;

typedef struct _jc_java_awt_event_MouseEvent$fields_struct	_jc_java_awt_event_MouseEvent$fields_struct;
typedef const struct _jc_java_awt_event_MouseEvent$vmethods	_jc_java_awt_event_MouseEvent$vmethods;
typedef const struct _jc_java_awt_event_MouseEvent$vtable	_jc_java_awt_event_MouseEvent$vtable;
typedef const struct _jc_java_awt_event_MouseEvent$vtype	_jc_java_awt_event_MouseEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_MouseEvent$fields_struct {
	jlong	serialVersionUID;
	jint	BUTTON1;
	jint	BUTTON2;
	jint	BUTTON3;
	jint	MOUSE__5fCLICKED;
	jint	MOUSE__5fDRAGGED;
	jint	MOUSE__5fENTERED;
	jint	MOUSE__5fEXITED;
	jint	MOUSE__5fFIRST;
	jint	MOUSE__5fLAST;
	jint	MOUSE__5fMOVED;
	jint	MOUSE__5fPRESSED;
	jint	MOUSE__5fRELEASED;
	jint	MOUSE__5fWHEEL;
	jint	NOBUTTON;
};
extern _jc_java_awt_event_MouseEvent$fields_struct _jc_java_awt_event_MouseEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_MouseEvent$method$_init$99f370a90b8c3280(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean);
extern void _jc_java_awt_event_MouseEvent$method$_init$a87a8bf16ac0c0ff(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, jint);

// Virtual methods
extern jint _jc_java_awt_event_MouseEvent$method$getButton$e6a3d03528081a15(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern jint _jc_java_awt_event_MouseEvent$method$getClickCount$ecb090aca5be7402(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern struct _jc_java_awt_Point$object *_jc_java_awt_event_MouseEvent$method$getPoint$2b27e97e4e2dc494(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern jint _jc_java_awt_event_MouseEvent$method$getX$95f81a17f95fa138(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern jint _jc_java_awt_event_MouseEvent$method$getY$848e5d443e3420a7(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern jboolean _jc_java_awt_event_MouseEvent$method$isPopupTrigger$7b1b0f7b8df40097(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_java_awt_event_MouseEvent$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_io_ObjectInputStream$object *);
extern void _jc_java_awt_event_MouseEvent$method$translatePoint$04a76d3304c7c132(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getButton$e6a3d03528081a15;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getClickCount$ecb090aca5be7402;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getPoint$2b27e97e4e2dc494;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getX$95f81a17f95fa138;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getY$848e5d443e3420a7;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$isPopupTrigger$7b1b0f7b8df40097;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$translatePoint$04a76d3304c7c132;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseEvent$method$getMouseModifiersText$3350e721426aa908(_jc_env *, jint);

// Virtual methods structure
struct _jc_java_awt_event_MouseEvent$vmethods {
	jint	(*getButton$e6a3d03528081a15)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	jint	(*getClickCount$ecb090aca5be7402)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	struct _jc_java_awt_Point$object	*(*getPoint$2b27e97e4e2dc494)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	jint	(*getX$95f81a17f95fa138)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	jint	(*getY$848e5d443e3420a7)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	jboolean	(*isPopupTrigger$7b1b0f7b8df40097)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_io_ObjectInputStream$object *);
	void	(*translatePoint$04a76d3304c7c132)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, jint, jint);
};

// Vtable
struct _jc_java_awt_event_MouseEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
};

// Vtype
struct _jc_java_awt_event_MouseEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseEvent$refs {
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseEvent$sub_nonrefs {
	jint	x;
	jint	y;
	jint	clickCount;
	jint	button;
	jboolean	popupTrigger;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
};

// Object instance structure
struct _jc_java_awt_event_MouseEvent$object {
	_jc_java_awt_event_MouseEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseEvent$vtype	*vtype;
	_jc_java_awt_event_MouseEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseEvent$vtype _jc_java_awt_event_MouseEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseEvent$class_object;

#endif	/* _JC_java_awt_event_MouseEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/MouseEvent.h <==
// public class java.awt.event.MouseEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_InputEvent

#include "java/awt/event/InputEvent.h"

#ifndef _JC_java_awt_event_MouseEvent_H_
#define _JC_java_awt_event_MouseEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Point$object;
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseEvent$sub_refs	_jc_java_awt_event_MouseEvent$sub_refs;
typedef struct _jc_java_awt_event_MouseEvent$sub_nonrefs	_jc_java_awt_event_MouseEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseEvent$refs	_jc_java_awt_event_MouseEvent$refs;
typedef struct _jc_java_awt_event_MouseEvent$nonrefs	_jc_java_awt_event_MouseEvent$nonrefs;
typedef struct _jc_java_awt_event_MouseEvent$object	_jc_java_awt_event_MouseEvent$object;

typedef struct _jc_java_awt_event_MouseEvent$fields_struct	_jc_java_awt_event_MouseEvent$fields_struct;
typedef const struct _jc_java_awt_event_MouseEvent$vmethods	_jc_java_awt_event_MouseEvent$vmethods;
typedef const struct _jc_java_awt_event_MouseEvent$vtable	_jc_java_awt_event_MouseEvent$vtable;
typedef const struct _jc_java_awt_event_MouseEvent$vtype	_jc_java_awt_event_MouseEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_MouseEvent$fields_struct {
	jlong	serialVersionUID;
	jint	BUTTON1;
	jint	BUTTON2;
	jint	BUTTON3;
	jint	MOUSE__5fCLICKED;
	jint	MOUSE__5fDRAGGED;
	jint	MOUSE__5fENTERED;
	jint	MOUSE__5fEXITED;
	jint	MOUSE__5fFIRST;
	jint	MOUSE__5fLAST;
	jint	MOUSE__5fMOVED;
	jint	MOUSE__5fPRESSED;
	jint	MOUSE__5fRELEASED;
	jint	MOUSE__5fWHEEL;
	jint	NOBUTTON;
};
extern _jc_java_awt_event_MouseEvent$fields_struct _jc_java_awt_event_MouseEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_MouseEvent$method$_init$99f370a90b8c3280(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseEvent$method$_init$a87a8bf16ac0c0ff(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_event_MouseEvent$method$getButton$e6a3d03528081a15(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseEvent$method$getClickCount$ecb090aca5be7402(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Point$object *_jc_java_awt_event_MouseEvent$method$getPoint$2b27e97e4e2dc494(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseEvent$method$getX$95f81a17f95fa138(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseEvent$method$getY$848e5d443e3420a7(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_MouseEvent$method$isPopupTrigger$7b1b0f7b8df40097(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseEvent$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_MouseEvent$method$translatePoint$04a76d3304c7c132(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getButton$e6a3d03528081a15;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getClickCount$ecb090aca5be7402;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getPoint$2b27e97e4e2dc494;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getX$95f81a17f95fa138;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$getY$848e5d443e3420a7;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$isPopupTrigger$7b1b0f7b8df40097;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_awt_event_MouseEvent$method_info$translatePoint$04a76d3304c7c132;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseEvent$method$getMouseModifiersText$3350e721426aa908(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_event_MouseEvent$vmethods {
	jint	(*getButton$e6a3d03528081a15)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jint	(*getClickCount$ecb090aca5be7402)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Point$object	*(*getPoint$2b27e97e4e2dc494)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jint	(*getX$95f81a17f95fa138)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jint	(*getY$848e5d443e3420a7)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isPopupTrigger$7b1b0f7b8df40097)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
	void	(*translatePoint$04a76d3304c7c132)(_jc_env *, struct _jc_java_awt_event_MouseEvent$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_MouseEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
};

// Vtype
struct _jc_java_awt_event_MouseEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseEvent$refs {
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseEvent$sub_nonrefs {
	jint	x;
	jint	y;
	jint	clickCount;
	jint	button;
	jboolean	popupTrigger;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
};

// Object instance structure
struct _jc_java_awt_event_MouseEvent$object {
	_jc_java_awt_event_MouseEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseEvent$vtype	*vtype;
	_jc_java_awt_event_MouseEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseEvent$vtype _jc_java_awt_event_MouseEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseEvent$class_object;

#endif	/* _JC_java_awt_event_MouseEvent_H_ */
